# About Secretarium's Python package

This is not a usable Python package, but the name is reserved by Secretarium Ltd.

Visit secretarium.com/python for information about tools and products released by Secretarium for Python developers.

You can find other packages published by Secretarium at pypi.org/user/secretarium

See <www.secretarium.com/trademarks> for full details on Secretarium’s trademarks and how you may use them correctly.
